@@ -13,6 +13,7 @@ module Control.Wire.Prefab
       module Control.Wire.Prefab.Calculus,
       module Control.Wire.Prefab.Clock,
       module Control.Wire.Prefab.Event,
+      module Control.Wire.Prefab.Execute,
       module Control.Wire.Prefab.Queue,
       module Control.Wire.Prefab.Random,
       module Control.Wire.Prefab.Sample,
@@ -26,6 +27,7 @@ import Control.Wire.Prefab.Analyze
 import Control.Wire.Prefab.Calculus
 import Control.Wire.Prefab.Clock
 import Control.Wire.Prefab.Event
+import Control.Wire.Prefab.Execute
 import Control.Wire.Prefab.Queue
 import Control.Wire.Prefab.Random
 import Control.Wire.Prefab.Sample
