@@ -29,7 +29,7 @@ import Control.Wire.Types
 --
 -- * Depends: current instant.
 
-accum :: a -> Wire e (>~) (a -> a) a
+accum :: WirePure (>~) => a -> Wire e (>~) (a -> a) a
 accum x =
     mkPure $ \f -> x `seq` (Right x, accum (f x))
 
@@ -39,13 +39,13 @@ accum x =
 --
 -- * Depends: Current instant.
 
-atFirst :: (b -> b) -> Wire e (>~) b b
+atFirst :: WirePure (>~) => (b -> b) -> Wire e (>~) b b
 atFirst f = mkPure $ \x -> (Right (f x), identity)
 
 
 -- | Count upwards from the given starting value.
 
-countFrom :: Enum b => b -> Wire e (>~) a b
+countFrom :: (Enum b, WirePure (>~)) => b -> Wire e (>~) a b
 countFrom n = mkPure $ \_ -> n `seq` (Right n, countFrom (succ n))
 
 
@@ -54,5 +54,8 @@ countFrom n = mkPure $ \_ -> n `seq` (Right n, countFrom (succ n))
 --
 -- * Depends: current instant.
 
-countStep :: Num a => a -> Wire e (>~) a a
-countStep x = mkPure $ \dx -> x `seq` (Right x, countStep (x + dx))
+countStep :: (Num b, WirePure (>~)) => b -> Wire e (>~) b b
+countStep x =
+    mkPure $ \dx ->
+        x `seq`
+        (Right x, countStep (x + dx))
