@@ -9,7 +9,10 @@
 module Control.Wire.Tools
     ( -- * Arrow tools
       distA,
-      mapA
+      mapA,
+
+      -- * Utility functions
+      dup
     )
     where
 
@@ -24,6 +27,12 @@ distA []     = arr (const [])
 distA (c:cs) = arr (uncurry (:)) <<< c &&& distA cs
 
 
+-- | Duplicate a value into a tuple.
+
+dup :: a -> (a, a)
+dup x = (x, x)
+
+
 -- | Lift an arrow computation to lists of values.
 
 mapA :: ArrowChoice (>~) => (a >~ b) -> ([a] >~ [b])
