@@ -8,14 +8,20 @@
 
 module Control.Wire.Trans
     ( -- * Reexports
+      module Control.Wire.Trans.Clock,
       module Control.Wire.Trans.Combine,
       module Control.Wire.Trans.Exhibit,
+      module Control.Wire.Trans.Fork,
+      module Control.Wire.Trans.Memoize,
       module Control.Wire.Trans.Sample,
       module Control.Wire.Trans.Simple
     )
     where
 
+import Control.Wire.Trans.Clock
 import Control.Wire.Trans.Combine
 import Control.Wire.Trans.Exhibit
+import Control.Wire.Trans.Fork
+import Control.Wire.Trans.Memoize
 import Control.Wire.Trans.Sample
 import Control.Wire.Trans.Simple
